{ pkgs, config, lib, ... }: {
  imports = [
    ./hardware-configuration.nix
    ../../client.nix

    ../../features/bluetooth.nix
    ../../features/nas0.nix
    ../../features/no-rgb.nix
    ../../features/nvidia-no-vrr.nix
    ../../features/nvidia.nix
    ../../features/plasma6.nix
    ../../features/podman.nix
    ../../features/protonvpn.nix
    ../../features/sound
    ../../features/steam.nix
    ../../features/tailscale.nix
    ../../features/telemetry
    ../../features/wine.nix

    ./scarlett-air.nix
  ];

  home-manager.users.noe = import ../../../home-manager/noe/hosts/aerial.nix;
  
  environment.etc."X11/xorg.conf" = {
    source = ./xorg.conf;
  };

  networking.hostName = "aerial";
  system.stateVersion = "24.05";

  fileSystems."/mnt/wumbo" = {
    device = "/dev/disk/by-uuid/804c5fa2-cf78-4c18-a956-a5b60ea33619";
    fsType = "ext4";
  };

  internal.nas0.useSMB = true;
  internal.wine = pkgs.wine;

  environment.systemPackages = with pkgs; [
    python3
  ];

  boot.binfmt.emulatedSystems = [ "aarch64-linux" ];

  networking.firewall.allowedTCPPorts = [ 42069 8000 ];
  networking.firewall.allowedUDPPorts = [ 42069 ];

  networking.nameservers = lib.mkForce [
    "10.100.69.69"
    "10.0.0.1"
  ];

}
