{ config, pkgs, ... }: {
  nixpkgs.config.permittedInsecurePackages = [
    "aspnetcore-runtime-6.0.36"
    "aspnetcore-runtime-wrapped-6.0.36"
    "dotnet-sdk-6.0.428"
    "dotnet-sdk-wrapped-6.0.428"
  ];

  users.groups.data = {
    gid = 1069;
  };
  users.users.data = {
    uid = 1069;
    isNormalUser = true;
    group = "data";
  };

  internal.nas0.mountGid = config.users.groups.data.gid;
  internal.nas0.mountUid = config.users.users.data.uid;

  services.lidarr.enable = true;
  services.lidarr.user = "data";
  services.lidarr.group = "data";
  services.lidarr.package = pkgs.master.lidarr;

  services.sonarr.enable = true;
  services.sonarr.user = "data";
  services.sonarr.group = "data";
  services.sonarr.package = pkgs.master.sonarr;

  services.radarr.enable = true;
  services.radarr.user = "data";
  services.radarr.group = "data";
  services.radarr.package = pkgs.master.radarr;

  services.bazarr.enable = true;
  services.bazarr.user = "data";
  services.bazarr.group = "data";
  services.bazarr.package = pkgs.master.bazarr;

  services.prowlarr.enable = true;
  services.prowlarr.package = pkgs.master.prowlarr;

  systemd.units.radarr.upheldBy = ["mnt-nas0.mount"];
  systemd.units.lidarr.upheldBy = ["mnt-nas0.mount"];
  systemd.units.sonarr.upheldBy = ["mnt-nas0.mount"];
}
